@@ -96,7 +96,7 @@ BEGIN {
    }
 
    our $fa_custom_code='fa_code.pm';
-   our $fa_menu_config='fa_menu.pm';
+   # our $fa_menu_config='fa_menu.pm';
 
 }
 
